Gamma — PyMedPhys

Toggle navigation sidebar
Toggle in-page Table of Contents

# Gamma

- Speeding up gamma calculations
- Gamma from 1D ASCII data
  - Getting the demo .csv files
  - Calculate gamma
  - Plot the histogram of gamma index
  - Display gamma together with dose points
- The Effects of Noise on Gamma
  - Defining an example dose reference
  - Defining an example evaluation dose
  - Seeing a dose difference
  - Evaluation Gamma
  - Investigating the effect of noise
  - Conclusion
- Gamma from DICOM
  - Getting the demo DICOM files
  - Calculate and display Gamma
  - Plotting the Dose and the Gamma